==> Paws-0.31.tar.gz: Paws-0.31/lib/Paws/ELB/LBCookieStickinessPolicy.pm <==
package Paws::ELB::LBCookieStickinessPolicy;
  use Moose;
  has CookieExpirationPeriod => (is => 'ro', isa => 'Int');
  has PolicyName => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ELB::LBCookieStickinessPolicy

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::ELB::LBCookieStickinessPolicy object:

  $service_obj->Method(Att1 => { CookieExpirationPeriod => $value, ..., PolicyName => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::ELB::LBCookieStickinessPolicy object:

  $result = $service_obj->Method(...);
  $result->Att1->CookieExpirationPeriod

=head1 DESCRIPTION

Information about a policy for duration-based session stickiness.

=head1 ATTRIBUTES


=head2 CookieExpirationPeriod => Int

  The time period, in seconds, after which the cookie should be
considered stale. If this parameter is not specified, the stickiness
session lasts for the duration of the browser session.


=head2 PolicyName => Str

  The name of the policy. This name must be unique within the set of
policies for this load balancer.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::ELB>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.42.tar.gz: Paws-0.42/lib/Paws/ELB/LBCookieStickinessPolicy.pm <==
package Paws::ELB::LBCookieStickinessPolicy;
  use Moose;
  has CookieExpirationPeriod => (is => 'ro', isa => 'Int');
  has PolicyName => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ELB::LBCookieStickinessPolicy

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::ELB::LBCookieStickinessPolicy object:

  $service_obj->Method(Att1 => { CookieExpirationPeriod => $value, ..., PolicyName => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::ELB::LBCookieStickinessPolicy object:

  $result = $service_obj->Method(...);
  $result->Att1->CookieExpirationPeriod

=head1 DESCRIPTION

Information about a policy for duration-based session stickiness.

=head1 ATTRIBUTES


=head2 CookieExpirationPeriod => Int

  The time period, in seconds, after which the cookie should be
considered stale. If this parameter is not specified, the stickiness
session lasts for the duration of the browser session.


=head2 PolicyName => Str

  The name of the policy. This name must be unique within the set of
policies for this load balancer.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::ELB>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
